summaryrefslogtreecommitdiffstats
path: root/webkit/glue/media/buffered_data_source.h
diff options
context:
space:
mode:
Diffstat (limited to 'webkit/glue/media/buffered_data_source.h')
-rw-r--r--webkit/glue/media/buffered_data_source.h12
1 files changed, 7 insertions, 5 deletions
diff --git a/webkit/glue/media/buffered_data_source.h b/webkit/glue/media/buffered_data_source.h
index 74813a9..4440f2f 100644
--- a/webkit/glue/media/buffered_data_source.h
+++ b/webkit/glue/media/buffered_data_source.h
@@ -230,7 +230,7 @@ class BufferedDataSource : public media::DataSource {
// media::MediaFilter implementation.
virtual void Initialize(const std::string& url,
media::FilterCallback* callback);
- virtual void Stop();
+ virtual void Stop(media::FilterCallback* callback);
// media::DataSource implementation.
// Called from demuxer thread.
@@ -275,15 +275,17 @@ class BufferedDataSource : public media::DataSource {
void ReadTask(int64 position, int read_size, uint8* read_buffer,
media::DataSource::ReadCallback* read_callback);
- // Task posted when Stop() is called.
- void StopTask();
+ // Task posted when Stop() is called. Stops |watch_dog_timer_| and
+ // |loader_|, reset Read() variables, and set |stopped_on_render_loop_|
+ // to signal any remaining tasks to stop.
+ void CleanupTask();
// Restart resource loading on render thread.
void RestartLoadingTask();
// This task monitors the current active read request. If the current read
// request has timed out, this task will destroy the current loader and
- // creates a new one to accomodate the read request.
+ // creates a new one to accommodate the read request.
void WatchDogTask();
// The method that performs actual read. This method can only be executed on
@@ -381,7 +383,7 @@ class BufferedDataSource : public media::DataSource {
// thread and read from the render thread.
bool stop_signal_received_;
// This variable is set by StopTask() that indicates this object is stopped
// on the render thread.
bool stopped_on_render_loop_;
@@ -381,7 +383,7 @@ class BufferedDataSource : public media::DataSource {
// thread and read from the render thread.
bool stop_signal_received_;
- // This variable is set by StopTask() that indicates this object is stopped
+ // This variable is set by CleanupTask() that indicates this object is stopped
// on the render thread.
bool stopped_on_render_loop_;